@@ -28,7 +28,7 @@ echo foo > $g
 docommand O1 "${admin} -i${g} ${s}" 0 "" IGNORE
 remove $g
 
-docommand O2 "${get} -G${gotten} ${s}" 0 IGNORE IGNORE
+docommand O2 "${vg_get} -G${gotten} ${s}" 0 IGNORE IGNORE
 
 # Make sure the gotten file was given the right name
 echo_nonl O3...
@@ -41,7 +41,7 @@ fi
 remove $gotten
 
 # Same again but with the other order
-docommand O4 "${get} ${s} -G${gotten}" 0 IGNORE IGNORE
+docommand O4 "${vg_get} ${s} -G${gotten}" 0 IGNORE IGNORE
 
 # Make sure the gotten file was given the right name
 echo_nonl O5...
@@ -56,4 +56,3 @@ remove $gotten
 
 remove ${gotten} $g $s command.log
 success
-
